@@ -1,6 +1,9 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# bin/otrs.AddUser2Group.pl - Add User to a Group
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# --
+# $Id: otrs.AddUser2Group.pl,v 1.3 2010/08/06 17:49:20 cr Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +12,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -24,8 +27,6 @@ use warnings;
 use File::Basename;
 use FindBin qw($RealBin);
 use lib dirname($RealBin);
-use lib dirname($RealBin) . '/Kernel/cpan-lib';
-use lib dirname($RealBin) . '/Custom';
 
 use Kernel::Config;
 use Kernel::System::Encode;
@@ -36,7 +37,18 @@ use Kernel::System::Main;
 use Kernel::System::User;
 use Kernel::System::Group;
 
+my %Param;
 my %CommonObject;
+my %Opts;
+
+use Getopt::Std;
+getopt( 'guph', \%Opts );
+
+if ( $Opts{h} || !$Opts{g} || !$Opts{u} || !$Opts{p} ) {
+    print STDERR
+        "Usage: bin/otrs.AddUser2Group -g groupname -u username -p ro|rw\n";
+    exit;
+}
 
 # create common objects
 $CommonObject{ConfigObject} = Kernel::Config->new(%CommonObject);
@@ -51,18 +63,6 @@ $CommonObject{DBObject}    = Kernel::System::DB->new(%CommonObject);
 $CommonObject{UserObject}  = Kernel::System::User->new(%CommonObject);
 $CommonObject{GroupObject} = Kernel::System::Group->new(%CommonObject);
 
-my %Param;
-my %Opts;
-
-use Getopt::Std;
-getopt( 'guph', \%Opts );
-
-if ( $Opts{h} || !$Opts{g} || !$Opts{u} || !$Opts{p} ) {
-    print STDERR
-        "Usage: $0 -g groupname -u username -p ro|rw\n";
-    exit;
-}
-
 # user id
 $Param{UserID} = '1';
 
@@ -74,7 +74,8 @@ $Param{UserLogin}                = $Opts{u};
 $Param{Group}                    = $Opts{g};
 
 unless (
-    $Param{UID} =
+    $Param{UID}
+    =
     $CommonObject{UserObject}->UserLookup( UserLogin => $Param{UserLogin} )
     )
 {
